A module containing various helper traits and types mostly useful to work with tuples at compile time
Structs
- Tuple
Index0 - A type level marker to be used as index into tuples
- Tuple
Index1 - A type level marker to be used as index into tuples
- Tuple
Index2 - A type level marker to be used as index into tuples
- Tuple
Index3 - A type level marker to be used as index into tuples
- Tuple
Index4 - A type level marker to be used as index into tuples
- Tuple
Index5 - A type level marker to be used as index into tuples
- Tuple
Index6 - A type level marker to be used as index into tuples
- Tuple
Index7 - A type level marker to be used as index into tuples
- Tuple
Index8 - A type level marker to be used as index into tuples
- Tuple
Index9 - A type level marker to be used as index into tuples
- Tuple
Index10 - A type level marker to be used as index into tuples
- Tuple
Index11 - A type level marker to be used as index into tuples
- Tuple
Index12 - A type level marker to be used as index into tuples
- Tuple
Index13 - A type level marker to be used as index into tuples
- Tuple
Index14 - A type level marker to be used as index into tuples
- Tuple
Index15 - A type level marker to be used as index into tuples
- Tuple
Index16 - A type level marker to be used as index into tuples
Traits
- Append
ToTuple - A type level helper trait to append another element to a tuple
- Concat
Tuples - A type level helper to concat two tuples
- IsPrimary
KeyIndex - A marker trait that says a given type could be used as type level index into a tuple
- Named
Table - A marker trait for query sources with a name
- Primary
KeyInput Object - Tuple
Index - A trait to have a type level index into a tuple
- UnRef
- A helper trait to transform a tuple of references into a tuple of owned values at type system level
- UnRef
Clone - A helper trait to transform a tuple of references into a tuple of owned values at type system level