pub trait AppendToTuple<T> {
type Out;
const LENGHT: usize;
}Expand description
A type level helper trait to append another element to a tuple
Self is the existing tuple, T the element that is appended
Required Associated Constants
Required Associated Types
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.