Module query_builder
wundergraph
0.1.2
Module query_
builder
Module Items
Modules
In crate wundergraph
wundergraph
Module
query_
builder
This module contains functionality used by wundergraph to convert a GraphQL request as sql query.
Modules

mutations
This module contains all functionality that is needed to implement mutations
selection
This module contains all functionality that is needed to implement a wundergraph entity
types
This module contains several helper types used constructing the final graphql model